==> redis-replicator-3.2.0-sources.jar: com/moilioncircle/redis/replicator/cmd/impl/XGroupCreateCommand.java <==
/*
 * Copyright 2016-2018 Leon Chen
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.moilioncircle.redis.replicator.cmd.impl;

/**
 * @author Leon Chen
 * @since 2.6.0
 */
public class XGroupCreateCommand extends XGroupCommand {

    private static final long serialVersionUID = 1L;

    private byte[] key;

    private byte[] group;

    private byte[] id;
    
    private boolean mkStream;

    public XGroupCreateCommand() {

    }
    
    public XGroupCreateCommand(byte[] key, byte[] group, byte[] id, boolean mkStream) {
        this.key = key;
        this.group = group;
        this.id = id;
        this.mkStream = mkStream;
    }

    public byte[] getKey() {
        return key;
    }

    public void setKey(byte[] key) {
        this.key = key;
    }

    public byte[] getGroup() {
        return group;
    }

    public void setGroup(byte[] group) {
        this.group = group;
    }

    public byte[] getId() {
        return id;
    }

    public void setId(byte[] id) {
        this.id = id;
    }
    
    public boolean isMkStream() {
        return mkStream;
    }
    
    public void setMkStream(boolean mkStream) {
        this.mkStream = mkStream;
    }
}

==> redis-replicator-3.4.0-sources.jar: com/moilioncircle/redis/replicator/cmd/impl/XGroupCreateCommand.java <==
/*
 * Copyright 2016-2018 Leon Chen
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.moilioncircle.redis.replicator.cmd.impl;

/**
 * @author Leon Chen
 * @since 2.6.0
 */
public class XGroupCreateCommand extends XGroupCommand {

    private static final long serialVersionUID = 1L;

    private byte[] group;
    private byte[] id;
    private boolean mkStream;

    public XGroupCreateCommand() {
    }
    
    public XGroupCreateCommand(byte[] key, byte[] group, byte[] id, boolean mkStream) {
        super(key);
        this.group = group;
        this.id = id;
        this.mkStream = mkStream;
    }

    public byte[] getGroup() {
        return group;
    }

    public void setGroup(byte[] group) {
        this.group = group;
    }

    public byte[] getId() {
        return id;
    }

    public void setId(byte[] id) {
        this.id = id;
    }
    
    public boolean isMkStream() {
        return mkStream;
    }
    
    public void setMkStream(boolean mkStream) {
        this.mkStream = mkStream;
    }
}
